package cc.fascinated.bat.common;

import lombok.Getter;
import lombok.extern.log4j.Log4j2;

import java.io.IOException;
import java.util.Properties;

/**
 * @author Fascinated (fascinated7)
 */
@Getter
@Log4j2(topic = "Build Data")
public class BuildData {
    /**
     * The commit hash of the build
     */
    private final String buildId;

    /**
     * The version of the build
     */
    private final String buildVersion;

    /**
     * The date of the build
     */
    private final String buildDate;

    public BuildData() {
        // get git.properties from resources
        Properties properties = new Properties();
        try {
            properties.load(getClass().getClassLoader().getResourceAsStream("git.properties"));
        } catch (IOException ex) {
            log.error("Failed to load git.properties", ex);
        }

        this.buildId = properties.getProperty("git.commit.id.abbrev");
        this.buildVersion = properties.getProperty("git.build.version");
        this.buildDate = properties.getProperty("git.build.time");
    }

    /**
     * Gets the version of the bot
     *
     * @return the version
     */
    public String getVersion() {
        return "Bat - v%s-%s".formatted(buildVersion, buildId);
    }
}
